<#
bvr_converter.ps1 ver. 1.10 | 3/2020 by Mike, Thixotropic, & LDM

This powershell script converts .BVR files to .MP4 files, preserving the original file's timestamp. 
Options include keeping the original size or scaling to 1/2, 1/3, or 1/4 of the original 
video size/resolution. 

You can manually convert a single file with a command line like this: 

  ffmpeg -n -loglevel error -i inputfile.bvr -vcodec libx264 -crf 30 outputfile.mp4

For more info on using ffmpeg, see: https://www.ffmpeg.org/
For more on the CRF parameter, see: https://slhck.info/video/2017/02/24/crf-guide.html


#>

################################
# Configuration settings start
################################

#######
# Source directory where the .BVR files to be converted are found. DO NOT use a trailing slash (\).
# For example, "C:\BlueIris\Stored"
$source_dir = "C:\BlueIris\Stored"

####### 
# Target directory where the converted .MP4 files will stored. DO NOT use a trailing slash (\).
# You will probably want to change this to another directory, a network drive, attached storage, etc. 
# For example, "C:\BlueIris\Stored"
$target_dir = "C:\BlueIris\Stored"


#######
# Pause time between conversions. Useful to avoid overloading the PC doing the converting.
# Value is in seconds; typically 1 or 2 seconds is plenty, but adjust as needed. 
$pause_time = 2


####### 
# The actual command line params for conversion. Don't change these if you don't know what you're doing. 
# UNCOMMENT ONE AND ONLY ONE LINE BELOW

# convert video with no size scaling - this is the default. Files are normally smaller by 20 to 50 percent.
$ffmpeg_params = "-n -loglevel error -i $source_dir\$oldvid -vcodec libx264 -crf 30 $source_dir\$newvid"

# Convert and scale video to 1/2 size - produces MUCH smaller videos with a minor loss of resolution.
#$ffmpeg_params = "-n -loglevel error -i $source_dir\$oldvid -vcodec libx264 -crf 30 -vf \"scale=iw/2:ih/2\" $source_dir\$newvid"

# Convert and also scale video to 1/3 size - produces much, much smaller videos with some loss of resolution.
#$ffmpeg_params = "-n -loglevel error -i $source_dir\$oldvid -vcodec libx264 -crf 30 -vf \"scale=iw/3:ih/3\" $source_dir\$newvid"

# Convert and also scale video to 1/4 size - produces ridiculously small videos suitable for sending by text ot email. 
#$ffmpeg_params = "-n -loglevel error -i $source_dir\$oldvid -vcodec libx264 -crf 30 -vf \"-vf "scale=iw/4:ih/4\" $source_dir\$newvid"

################################
# Configuration settings stop
################################


# pop into the source directory
cd $source_dir 

echo "Source directory: $source_dir "
echo "Target directory: $target_dir "

# get a list of all the .BVR files
$oldvids = Get-ChildItem -Path $source_dir -Filter "*.bvr"

# step through the .BVR files and convert them
foreach ($oldvid in $oldvids) {

    # get the timestamp of the original file 
    $orgtimestamp = (Get-Item $oldvid).LastWriteTime.toString()

    # change the extension from .bvr to .mp4 
    $newvid = [io.path]::ChangeExtension($oldvid, '.mp4')
    
    # print the source file name and timestamp for reference. You can comment this out if you want. 
    echo "Video source file: $source_dir\$oldvid "
    echo "Timestamp: $orgtimestamp "

    echo "FFMPEG comand: ffmpeg $ffmpeg_params"

    # this is where all the magic happens...
    Invoke-Expression "ffmpeg $ffmpeg_params"


    # write the original timestamp to the converted file 
    (Get-Item $newvid).LastWriteTime=($orgtimestamp)

    # pause time, if any
    if($pause_time -gt 0){Start-Sleep -s $pause_time}

    
    # move the file? 
    if($source_dir -ne $target_dir){
    # move the file to the destination target directory 
        echo "Moving file $newvid..."
        Move-Item -Path $source_dir\$newvid -Destination $target_dir\$newvid
    }



}

echo "Conversion complete."




